FatFs

Struct FatFs 

pub struct FatFs { /* private fields */ }

Implementations

Source

impl FatFs

pub fn new(disk: Box<dyn Disk>, scope: ExecutionScope) -> Result<Self, Error>

Create a new FatFs using the given ReadWriteSeek as the disk.

pub fn filesystem(&self) -> &FatFilesystem

pub fn is_present(&self) -> bool

pub fn get_root(&self) -> Result<Arc<FatDirectory>, Status>

Get the root directory of this filesystem. The caller must call close() on the returned entry when it’s finished with it.

pub fn handle_admin( &self, scope: &ExecutionScope, req: AdminRequest, ) -> Option<AdminShutdownResponder>

pub fn shut_down(self) -> Result<(), Status>

Shut down the filesystem.

Preconditions

This method requires exclusive ownership of the underlying FatFilesystem (held via Rc). The caller must ensure that all other references (e.g., outstanding VFS connections, active file/directory handles) have been dropped before calling this.

If there are outstanding references, Rc::into_inner will fail, and this method will return Err(Status::BAD_STATE) without unmounting the filesystem, to prevent potential Use-After-Free (UAF) bugs.

Typically, one should shut down the VFS scope and wait for all connections to close (e.g., via scope.wait().await) before invoking this.